# garan

[![PyPI version](https://badge.fury.io/py/Garen.svg)](https://badge.fury.io/py/Garen)

# 文档

[中文文档](README-zh.md)

easy use proxy app for web develop



# design 

![xx](./docs/images/design.png)

# 捐赠

<img src="https://ws4.sinaimg.cn/large/006tNc79ly1fl4wwvbz15j30u015575y.jpg" width="320">